# -*- coding: utf-8 -*-

# Authors: Alejandro J. Cura <alecu@canonical.com>
# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The user interface for the control panel for Ubuntu One."""

from PyQt4 import QtGui

from ubuntuone.controlpanel import backend
from ubuntuone.controlpanel.logger import setup_logging, log_call
from ubuntuone.controlpanel.gui.qt.ui import controlpanel_ui


logger = setup_logging('qt.controlpanel')


class ControlPanel(QtGui.QWidget):
    """The Control Panel widget"""

    def __init__(self, parent=None):
        """Initialize the UI of the widget."""
        QtGui.QWidget.__init__(self, parent)
        self.ui = controlpanel_ui.Ui_Form()
        self.ui.setupUi(self)

        self.backend = backend.ControlBackend()

        logger.debug('%s: started.', self.__class__.__name__)
        self.get_account_info()

    def get_account_info(self):
        """Get and update the account info from the webservice."""
        d = self.backend.account_info()
        d.addCallback(self.got_account_info)

    @log_call(logger.debug)
    def got_account_info(self, account_info):
        """Set the account info in all tabs."""
        self.ui.profile_tab.update_account_info(account_info)
        self.ui.services_tab.update_account_info(account_info)
