# -*- coding: utf-8 -*-

# Authors: Natalia B Bidart <natalia.bidart@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the Control Panel."""

from ubuntuone.controlpanel.gui.qt import controlpanel as gui
from ubuntuone.controlpanel.gui.qt.tests import (BaseTestCase, NO_OP,
                                                 SAMPLE_ACCOUNT_INFO)


class ControlPanelTestCase(BaseTestCase):
    """Test the qt control panel."""

    innerclass_ui = gui.controlpanel_ui
    innerclass_name = "Ui_Form"
    class_ui = gui.ControlPanel

    def setUp(self):
        """Initialize this test instance."""
        self.patch(gui.ControlPanel, "get_account_info", NO_OP)
        super(ControlPanelTestCase, self).setUp()

    def test_backend(self):
        """Backend is created."""
        self.assertIsInstance(self.ui.backend,
                              gui.backend.ControlBackend)

    def test_got_account_info_updates_profile(self):
        """Test the got_account_info method."""
        self.patch(self.ui.ui.profile_tab, "update_account_info",
                   self._set_called)
        self.ui.got_account_info(SAMPLE_ACCOUNT_INFO)
        expected = ((SAMPLE_ACCOUNT_INFO,), {})
        self.assertEqual(self._called, expected)

    def test_got_account_info_updates_services(self):
        """Test the got_account_info method."""
        self.patch(self.ui.ui.services_tab, "update_account_info",
                   self._set_called)
        self.ui.got_account_info(SAMPLE_ACCOUNT_INFO)
        expected = ((SAMPLE_ACCOUNT_INFO,), {})
        self.assertEqual(self._called, expected)
